summaryrefslogtreecommitdiff
path: root/cli
diff options
context:
space:
mode:
authorRocky Madden <git@rockymadden.com>2012-12-16 10:37:11 -0700
committerRocky Madden <git@rockymadden.com>2012-12-16 10:37:11 -0700
commit93722dfe64a93d2259ce9fa7d04da2eab8b64e1c (patch)
treecbabbac479b731103d879616b930ba3a096f0cb6 /cli
parent0c19b374c1c19a705d613b37451e92e6b27d7fe4 (diff)
downloadstringmetric-93722dfe64a93d2259ce9fa7d04da2eab8b64e1c.tar.gz
stringmetric-93722dfe64a93d2259ce9fa7d04da2eab8b64e1c.tar.bz2
stringmetric-93722dfe64a93d2259ce9fa7d04da2eab8b64e1c.zip
Changed group from org.hashtree.stringmetric to com.rockymadden.stringmetric.
Diffstat (limited to 'cli')
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/Command.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/Command.scala)2
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/OptionMap.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/OptionMap.scala)2
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/OptionMapType.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/OptionMapType.scala)2
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/package.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/package.scala)2
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithm.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithm.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/package.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/package.scala)2
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisAlgorithm.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/soundexAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithm.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/soundexMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/diceSorensenMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/hammingMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/hammingMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/jaroMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/jaroWinklerMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/levenshteinMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/nGramAlgorithm.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/nGramAlgorithm.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/nGramMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/nGramMetric.scala)8
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/package.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/package.scala)2
-rwxr-xr-xcli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/weightedLevenshteinMetric.scala (renamed from cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/weightedLevenshteinMetric.scala)8
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/OptionMapSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/OptionMapSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/OptionMapTypeSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/OptionMapTypeSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisAlgorithmSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/soundexMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/diceSorensenMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/hammingMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/hammingMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/jaroMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/levenshteinMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/nGramAlgorithmSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/nGramAlgorithmSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/nGramMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/nGramMetricSpec.scala)4
-rwxr-xr-xcli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/weightedLevenshteinMetricSpec.scala (renamed from cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/weightedLevenshteinMetricSpec.scala)4
44 files changed, 118 insertions, 118 deletions
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/Command.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/Command.scala
index c856374..a7daf3c 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/Command.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/Command.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli
+package com.rockymadden.stringmetric.cli
/** Defines the traits and provides basic implementations of a command. Commands are always implemented as objects. */
trait Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/OptionMap.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/OptionMap.scala
index 8489ca0..ede8a5c 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/OptionMap.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/OptionMap.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli
+package com.rockymadden.stringmetric.cli
import scala.annotation.tailrec
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/OptionMapType.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/OptionMapType.scala
index b52cc9e..6dfc869 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/OptionMapType.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/OptionMapType.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli
+package com.rockymadden.stringmetric.cli
sealed abstract class OptionMapType[T](protected[this] val stringSelf: String) {
def get(): Option[T]
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/package.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/package.scala
index 45bc913..0a44f9a 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/package.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/package.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric
+package com.rockymadden.stringmetric
/**
* Provides core CLI functionality. Note that some things might look sloppy (e.g. access modifiers, broad imports,
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/package.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/package.scala
index 59761d1..59a9df5 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/package.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/package.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli
+package com.rockymadden.stringmetric.cli
/** Provides core phonetic CLI functionality. */
package object phonetic {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/package.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/package.scala
index 500ab23..cf1b132 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/package.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/package.scala
@@ -1,4 +1,4 @@
-package org.hashtree.stringmetric.cli
+package com.rockymadden.stringmetric.cli
/** Provides core similarity CLI functionality. */
package object similarity {
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/OptionMapSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/OptionMapSpec.scala
index 23821c6..a3a1990 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/OptionMapSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/OptionMapSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli
+package com.rockymadden.stringmetric.cli
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/OptionMapTypeSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/OptionMapTypeSpec.scala
index 8f4d4bc..178a825 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/OptionMapTypeSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/OptionMapTypeSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli
+package com.rockymadden.stringmetric.cli
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala
index 72258c5..7fb4f29 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneAlgorithmSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneMetricSpec.scala
index 2f72e39..e7d56d1 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala
index caaa3e9..1062404 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisAlgorithmSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisMetricSpec.scala
index 3f5a346..bcc2a6a 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisAlgorithmSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisAlgorithmSpec.scala
index 2567221..428b5b3 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisAlgorithmSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisAlgorithmSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisMetricSpec.scala
index eddee0a..e48b967 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala
index a3265b7..fc014d0 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexAlgorithmSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala
index 9588f4f..b3e8642 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala
index 16ce3be..8c08f08 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/soundexAlgorithmSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/soundexMetricSpec.scala
index b245996..79434dc 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/phonetic/soundexMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/diceSorensenMetricSpec.scala
index 8d59172..090f278 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/diceSorensenMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/hammingMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/hammingMetricSpec.scala
index ac54e0e..69ed881 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/hammingMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/hammingMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/jaroMetricSpec.scala
index 192007b..df5bd3f 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/jaroMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala
index e5c8427..3515e1b 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/jaroWinklerMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/levenshteinMetricSpec.scala
index 5f5f900..c15e23b 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/levenshteinMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/nGramAlgorithmSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/nGramAlgorithmSpec.scala
index b041e14..b68d5bb 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/nGramAlgorithmSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/nGramAlgorithmSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/nGramMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/nGramMetricSpec.scala
index c4f5689..f6a498b 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/nGramMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/nGramMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/weightedLevenshteinMetricSpec.scala b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/weightedLevenshteinMetricSpec.scala
index dc3e898..bd2c936 100755
--- a/cli/source/test/scala/org/hashtree/stringmetric/cli/similarity/weightedLevenshteinMetricSpec.scala
+++ b/cli/source/test/scala/com/rockymadden/stringmetric/cli/similarity/weightedLevenshteinMetricSpec.scala
@@ -1,6 +1,6 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.ScalaTest
+import com.rockymadden.stringmetric.ScalaTest
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithm.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneAlgorithm.scala
index 09f75c8..e12e020 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneAlgorithm.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneAlgorithm.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.MetaphoneAlgorithm
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.MetaphoneAlgorithm
/**
* The metaphoneAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
* string, per the Metaphone algorithm.
*/
object metaphoneAlgorithm extends Command {
@@ -1,10 +1,10 @@
/**
- * The metaphoneAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
+ * The metaphoneAlgorithm [[com.rockymadden.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
* string, per the Metaphone algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneMetric.scala
index 5ba01c9..01bb4f2 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/metaphoneMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/metaphoneMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.MetaphoneMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.MetaphoneMetric
/**
* The metaphoneMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the Metaphone algorithm.
*/
object metaphoneMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The metaphoneMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
+ * The metaphoneMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the Metaphone algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithm.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisAlgorithm.scala
index 0d07a31..a318934 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisAlgorithm.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisAlgorithm.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.NysiisAlgorithm
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.NysiisAlgorithm
/**
* The nysiisAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
* string, per the NYSIIS algorithm.
*/
object nysiisAlgorithm extends Command {
@@ -1,10 +1,10 @@
/**
- * The nysiisAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
+ * The nysiisAlgorithm [[com.rockymadden.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
* string, per the NYSIIS algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisMetric.scala
index 86daa3e..09d172c 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/nysiisMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/nysiisMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.NysiisMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.NysiisMetric
/**
* The nysiisMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the NYSIIS algorithm.
*/
object nysiisMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The nysiisMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
+ * The nysiisMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the NYSIIS algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisAlgorithm.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisAlgorithm.scala
index fda8494..6c9d471 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisAlgorithm.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisAlgorithm.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.RefinedNysiisAlgorithm
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.RefinedNysiisAlgorithm
/**
* The refinedNysiisAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the refined NYSIIS algorithm.
*/
object refinedNysiisAlgorithm extends Command {
@@ -1,10 +1,10 @@
/**
- * The refinedNysiisAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
+ * The refinedNysiisAlgorithm [[com.rockymadden.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the refined NYSIIS algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisMetric.scala
index da9f17f..c096af1 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedNysiisMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedNysiisMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.RefinedNysiisMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.RefinedNysiisMetric
/**
* The refinedNysiisMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the refined NYSIIS algorithm.
*/
object refinedNysiisMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The refinedNysiisMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
+ * The refinedNysiisMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the refined NYSIIS algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala
index b51d630..6ae8d54 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexAlgorithm.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.RefinedSoundexAlgorithm
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.RefinedSoundexAlgorithm
/**
* The refinedSoundexAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the refined Soundex algorithm.
*/
object refinedSoundexAlgorithm extends Command {
@@ -1,10 +1,10 @@
/**
- * The refinedSoundexAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the
+ * The refinedSoundexAlgorithm [[com.rockymadden.stringmetric.cli.Command]]. Returns the phonetic representation of the
* passed string, per the refined Soundex algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexMetric.scala
index 157bbea..b426fe4 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/refinedSoundexMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/refinedSoundexMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.RefinedSoundexMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.RefinedSoundexMetric
/**
* The refinedSoundexMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the refined Soundex algorithm.
*/
object refinedSoundexMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The refinedSoundexMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
+ * The refinedSoundexMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the refined Soundex algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithm.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/soundexAlgorithm.scala
index 99fdd49..4a4600a 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexAlgorithm.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/soundexAlgorithm.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.SoundexAlgorithm
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.SoundexAlgorithm
/**
* The soundexAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
* string, per the Soundex algorithm.
*/
object soundexAlgorithm extends Command {
@@ -1,10 +1,10 @@
/**
- * The soundexAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
+ * The soundexAlgorithm [[com.rockymadden.stringmetric.cli.Command]]. Returns the phonetic representation of the passed
* string, per the Soundex algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/soundexMetric.scala
index 1ce31c0..c6e2d39 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/phonetic/soundexMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/phonetic/soundexMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.phonetic
+package com.rockymadden.stringmetric.cli.phonetic
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.phonetic.SoundexMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.phonetic.SoundexMetric
/**
* The soundexMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the Soundex algorithm.
*/
object soundexMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The soundexMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to determine if they are
+ * The soundexMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares two strings to determine if they are
* phonetically similarly, per the Soundex algorithm.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/diceSorensenMetric.scala
index 685ea16..0346038 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/diceSorensenMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/diceSorensenMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.DiceSorensenMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.DiceSorensenMetric
/**
* The diceSorensenMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the similarity of two strings using the
* Dice coefficient / Sorensen similarity index.
*/
object diceSorensenMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The diceSorensenMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the similarity of two strings using the
+ * The diceSorensenMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares the similarity of two strings using the
* Dice coefficient / Sorensen similarity index.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/hammingMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/hammingMetric.scala
index a325967..9293745 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/hammingMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/hammingMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.HammingMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.HammingMetric
/**
* The hammingMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two equal length
* strings are different from one another.
*/
object hammingMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The hammingMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two equal length
+ * The hammingMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares the number of characters that two equal length
* strings are different from one another.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/jaroMetric.scala
index d8a0076..27f1e8c 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/jaroMetric.scala
@@ -1,9 +1,9 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.JaroMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.JaroMetric
-/** The jaroMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to calculate the Jaro distance. */
+/** The jaroMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares two strings to calculate the Jaro distance. */
object jaroMetric extends Command {
override def main(args: Array[String]): Unit = {
val options = OptionMap(args)
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/jaroWinklerMetric.scala
index 39fda04..b2a65d4 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/jaroWinklerMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/jaroWinklerMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.JaroWinklerMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.JaroWinklerMetric
/**
* The jaroWinklerMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to calculate the Jaro-Winkler
* distance.
*/
object jaroWinklerMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The jaroWinklerMetric [[org.hashtree.stringmetric.cli.Command]]. Compares two strings to calculate the Jaro-Winkler
+ * The jaroWinklerMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares two strings to calculate the Jaro-Winkler
* distance.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/levenshteinMetric.scala
index 29de7d9..273a369 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/levenshteinMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/levenshteinMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.LevenshteinMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.LevenshteinMetric
/**
* The levenshteinMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two strings
* are different from one another via insertion, deletion, and substitution.
*/
object levenshteinMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The levenshteinMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two strings
+ * The levenshteinMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares the number of characters that two strings
* are different from one another via insertion, deletion, and substitution.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/nGramAlgorithm.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/nGramAlgorithm.scala
index 72436b0..58ea028 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/nGramAlgorithm.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/nGramAlgorithm.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.NGramAlgorithm
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.NGramAlgorithm
/**
* The nGramAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the N-Gram representation of the passed string.
*/
object nGramAlgorithm extends Command {
override def main(args: Array[String]): Unit = {
@@ -1,10 +1,10 @@
/**
- * The nGramAlgorithm [[org.hashtree.stringmetric.cli.Command]]. Returns the N-Gram representation of the passed string.
+ * The nGramAlgorithm [[com.rockymadden.stringmetric.cli.Command]]. Returns the N-Gram representation of the passed string.
*/
object nGramAlgorithm extends Command {
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/nGramMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/nGramMetric.scala
index 1dc7069..435a90a 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/nGramMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/nGramMetric.scala
@@ -1,10 +1,10 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.NGramMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.NGramMetric
/**
* The nGramMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the similarity of two strings using an N-Gram
* similarity index.
*/
object nGramMetric extends Command {
@@ -1,10 +1,10 @@
/**
- * The nGramMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the similarity of two strings using an N-Gram
+ * The nGramMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares the similarity of two strings using an N-Gram
* similarity index.
*/
diff --git a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/weightedLevenshteinMetric.scala b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/weightedLevenshteinMetric.scala
index 03f9c6d..18389a4 100755
--- a/cli/source/core/scala/org/hashtree/stringmetric/cli/similarity/weightedLevenshteinMetric.scala
+++ b/cli/source/core/scala/com/rockymadden/stringmetric/cli/similarity/weightedLevenshteinMetric.scala
@@ -1,11 +1,11 @@
-package org.hashtree.stringmetric.cli.similarity
+package com.rockymadden.stringmetric.cli.similarity
-import org.hashtree.stringmetric.cli._
-import org.hashtree.stringmetric.similarity.WeightedLevenshteinMetric
+import com.rockymadden.stringmetric.cli._
+import com.rockymadden.stringmetric.similarity.WeightedLevenshteinMetric
import scala.math.BigDecimal
/**
* The weightedLevenshteinMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two
* strings are different from one another via insertion, deletion, and substitution. Allows the invoker to indicate
* the weight each operation takes.
*/
@@ -1,11 +1,11 @@
import scala.math.BigDecimal
/**
- * The weightedLevenshteinMetric [[org.hashtree.stringmetric.cli.Command]]. Compares the number of characters that two
+ * The weightedLevenshteinMetric [[com.rockymadden.stringmetric.cli.Command]]. Compares the number of characters that two
* strings are different from one another via insertion, deletion, and substitution. Allows the invoker to indicate
* the weight each operation takes.